#!/usr/bin/env python3
# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:

import sys

from PyQt5.QtCore import pyqtSlot, QUrl, QTimer, QObject
from PyQt5.QtWidgets import QApplication
from PyQt5.QtWebKitWidgets import QWebView


class Toggler(QObject):

    def __init__(self, page, parent=None):
        super().__init__(parent)
        self.frames = []
        self.page = page
        self.connected = False
        self.timer = QTimer()
        self.timer.setInterval(100)
        self.timer.timeout.connect(self.toggle_connection)

    @pyqtSlot()
    def start(self):
        self.frames = [self.page.mainFrame()]
        self.frames += self.page.mainFrame().childFrames()
        self.timer.start()

    @pyqtSlot()
    def on_size_changed(self):
        print("size changed")

    @pyqtSlot()
    def toggle_connection(self):
        if self.connected:
            for f in self.frames:
                print("Disconnecting {!r}".format(f))
                f.iconChanged.disconnect(self.on_size_changed)
            self.connected = False
        else:
            for f in self.frames:
                print("Connecting {!r}".format(f))
                f.iconChanged.connect(self.on_size_changed)
            self.connected = True


app = QApplication(sys.argv)
wv = QWebView()
t = Toggler(page=wv.page())
wv.load(QUrl('http://www.kicker.de/'))
QTimer.singleShot(5000, t.start)
wv.show()

app.exec_()
